import java.util.Random;

/**
 * A utility class containing static methods used to generate random employee
 * objects for the Company simulation
 * 
 */
public class EmployeeUtils {

	private static final int WEEKLY_WAGE_BASE = 500;
	private static final int WEEKLY_WAGE_VARIANCE_RANGE = 200;

	private static final int WAGE_PER_SUBORDINATE_BASE = 200;
	private static final int WAGE_PER_SUBORDINATE_VARIANCE_RANGE = 50;

	private static Random rand = new Random();

	private static long id = 300000;

	public static long generateEmployeeId() {
		return ++id;
	}

	public static String generateEmployeeName() {
		String[] firstNames = { "David", "Kate", "Abrasha", "Moran",
				"Jean-Luc", "Boaz", "Nur", "Michael", "Jake", "Shlomo" };
		String[] lastNames = { "Lee", "Cohen", "Smith", "Picard", "Levi",
				"Taylor", "Anderson", "Jackson" };

		return firstNames[rand.nextInt(firstNames.length)] + " "
				+ lastNames[rand.nextInt(lastNames.length)];
	}

	public static double generateWeeklyWage() {
		return rand.nextInt(WEEKLY_WAGE_VARIANCE_RANGE) + WEEKLY_WAGE_BASE;
	}

	public static double generateWagePerSubordinate() {
		return rand.nextInt(WAGE_PER_SUBORDINATE_VARIANCE_RANGE)
				+ WAGE_PER_SUBORDINATE_BASE;
	}

	public static Programmer.ProgrammingLanguage generatePrefferedLanguage() {
		Programmer.ProgrammingLanguage[] values = Programmer.ProgrammingLanguage
				.values();
		int r = rand.nextInt(values.length);
		return values[r];

	}

	public static Programmer generateRandomProgrammer() {
		Programmer programmer = new Programmer(
				EmployeeUtils.generateEmployeeId(),
				EmployeeUtils.generateEmployeeName(), null,
				EmployeeUtils.generateWeeklyWage(),
				EmployeeUtils.generatePrefferedLanguage());

		return programmer;

	}

	public static QATester generateRandomQATester() {
		QATester tester = new QATester(EmployeeUtils.generateEmployeeId(),
				EmployeeUtils.generateEmployeeName(), null,
				EmployeeUtils.generateWeeklyWage());
		tester.addBugsFound(rand.nextInt(10));

		return tester;

	}

	public static Manager generateRandomManager() {
		Manager manager = new Manager(EmployeeUtils.generateEmployeeId(),
				EmployeeUtils.generateEmployeeName(), null,
				EmployeeUtils.generateWagePerSubordinate());

		return manager;

	}

}
